@@ -20,16 +20,16 @@
  *
  */
 
+#include <config.h>
 #include <accelerated.h>
-#if defined(ASM_X86_32) || defined(ASM_X86_64)
-# include <intel/aes-x86.h>
-# include <x86.h>
+#if defined(ASM_X86)
+# include <x86/aes-x86.h>
+# include <x86/x86.h>
 #endif
 
 void _gnutls_register_accel_crypto(void)
 {
-
-#if defined(ASM_X86_32) || defined(ASM_X86_64)
+#if defined(ASM_X86)
   if (_gnutls_have_cpuid() != 0)
     {
       register_x86_crypto ();
