@@ -7,7 +7,7 @@
  *
  * The GnuTLS is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
- * as published by the Free Software Foundation; either version 2.1 of
+ * as published by the Free Software Foundation; either version 3 of
  * the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful, but
@@ -15,10 +15,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
- * USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>
  *
  */
 
@@ -90,7 +88,7 @@ static const gnutls_sign_entry sign_algorithms[] = {
 
 /**
  * gnutls_sign_get_name:
- * @sign: is a sign algorithm
+ * @algorithm: is a sign algorithm
  *
  * Convert a #gnutls_sign_algorithm_t value to a string.
  *
@@ -98,8 +96,9 @@ static const gnutls_sign_entry sign_algorithms[] = {
  *   algorithm, or %NULL.
  **/
 const char *
-gnutls_sign_get_name (gnutls_sign_algorithm_t sign)
+gnutls_sign_get_name (gnutls_sign_algorithm_t algorithm)
 {
+  gnutls_sign_algorithm_t sign = algorithm;
   const char *ret = NULL;
 
   /* avoid prefix */
