@@ -557,7 +557,7 @@ gnutls_fingerprint (gnutls_digest_algorithm_t algo,
                     size_t * result_size)
 {
   int ret;
-  int hash_len = _gnutls_hash_get_algo_len (HASH2MAC (algo));
+  int hash_len = _gnutls_hash_get_algo_len (algo);
 
   if (hash_len < 0 || (unsigned) hash_len > *result_size || result == NULL)
     {
