@@ -202,21 +202,23 @@ mac_bench (int algo, int size)
   free (_key);
 }
 
-void benchmark_cipher (int debug_level)
+void benchmark_cipher (int init, int debug_level)
 {
   gnutls_global_set_log_function (tls_log_func);
   gnutls_global_set_log_level (debug_level);
-  gnutls_global_init ();
+  if (init)
+    {
+      gnutls_global_init ();
+      gnutls_rnd( GNUTLS_RND_NONCE, data, sizeof(data));
+    }
 
-  gnutls_rnd( GNUTLS_RND_NONCE, data, sizeof(data));
-
-  cipher_bench ( GNUTLS_CIPHER_AES_128_GCM, 16, 1);
-  cipher_mac_bench ( GNUTLS_CIPHER_AES_128_CBC, GNUTLS_MAC_SHA256, 16);
   cipher_mac_bench ( GNUTLS_CIPHER_AES_128_CBC, GNUTLS_MAC_SHA1, 16);
+  cipher_mac_bench ( GNUTLS_CIPHER_AES_128_CBC, GNUTLS_MAC_SHA256, 16);
+  cipher_bench ( GNUTLS_CIPHER_AES_128_GCM, 16, 1);
 
   mac_bench (GNUTLS_MAC_SHA1, 16);
-
   mac_bench (GNUTLS_MAC_SHA256, 16);
+  mac_bench (GNUTLS_MAC_SHA512, 16);
 
   cipher_bench (GNUTLS_CIPHER_3DES_CBC, 16, 0);
 
