@@ -5,7 +5,7 @@
 
 typedef void (*sighandler_t)(int);
 
-void benchmark_cipher (int debug_level);
+void benchmark_cipher (int init, int debug_level);
 void benchmark_tls (int debug_level);
 
 struct benchmark_st
