@@ -29,6 +29,7 @@
 #include <sys/socket.h>
 #include <sys/select.h>
 #include <unistd.h>
+#include <stdint.h>
 #include <fcntl.h>
 
 #include <gnutls/gnutls.h>
@@ -169,9 +170,11 @@ load_keys (void)
   int ret, i;
   gnutls_datum_t data = { NULL, 0 };
   gnutls_x509_crt_t crt_list[MAX_CRT];
+#ifdef ENABLE_PKCS11
   gnutls_pkcs11_privkey_t pkcs11_key;
+#endif
   gnutls_x509_privkey_t tmp_key;
-  uint8_t keyid[GNUTLS_OPENPGP_KEYID_SIZE];
+  unsigned char keyid[GNUTLS_OPENPGP_KEYID_SIZE];
 
   if (x509_certfile != NULL && x509_keyfile != NULL)
     {
