@@ -545,6 +545,39 @@ pkcs11_write (FILE * outfile, const char *url, const char *label,
   return;
 }
 
+void
+pkcs11_generate (FILE * outfile, const char *url, gnutls_pk_algorithm_t pk,
+              unsigned int bits,
+              const char *label, int private, int detailed,
+              unsigned int login, common_info_st * info)
+{
+  int ret;
+  unsigned int flags = 0;
+
+  if (login)
+    flags = GNUTLS_PKCS11_OBJ_FLAG_LOGIN;
+
+  pkcs11_common ();
+
+  if (url == NULL)
+    url = "pkcs11:";
+
+  if (private == 1)
+    flags |= GNUTLS_PKCS11_OBJ_FLAG_MARK_PRIVATE;
+  else if (private == 0)
+    flags |= GNUTLS_PKCS11_OBJ_FLAG_MARK_NOT_PRIVATE;
+
+  ret = gnutls_pkcs11_privkey_generate(url, pk, bits, label, flags);
+  if (ret < 0)
+    {
+      fprintf (stderr, "Error in %s:%d: %s\n", __func__, __LINE__,
+               gnutls_strerror (ret));
+      exit(1);
+    }
+
+  return;
+}
+
 void
 pkcs11_init (FILE * outfile, const char *url, const char *label,
              common_info_st * info)
@@ -783,6 +816,13 @@ const char *mech_list[] = {
   [0x2000] = "CKM_DSA_PARAMETER_GEN",
   [0x2001] = "CKM_DH_PKCS_PARAMETER_GEN",
   [0x2002] = "CKM_X9_42_DH_PARAMETER_GEN",
+  [0x1200] = "CKM_GOSTR3410_KEY_PAIR_GEN",
+  [0x1201] = "CKM_GOSTR3410",
+  [0x1202] = "CKM_GOSTR3410_WITH_GOSTR3411",
+  [0x1203] = "CKM_GOSTR3410_KEY_WRAP",
+  [0x1204] = "CKM_GOSTR3410_DERIVE",
+  [0x1210] = "CKM_GOSTR3411",
+  [0x1211] = "CKM_GOSTR3411_HMAC",
   [0x255] = "CKM_SHA224",
   [0x256] = "CKM_SHA224_HMAC",
   [0x257] = "CKM_SHA224_HMAC_GENERAL",
