@@ -33,7 +33,6 @@
 #include <sys/types.h>
 #include <string.h>
 #include <gnutls/gnutls.h>
-#include <gnutls/extra.h>
 #include <gnutls/openpgp.h>
 #include <sys/time.h>
 #include <sys/select.h>
@@ -702,6 +701,10 @@ listen_socket (const char *name, int listen_port, int socktype)
 
   for (ptr = res; ptr != NULL; ptr = ptr->ai_next)
     {
+#ifndef HAVE_IPV6
+      if (ptr->ai_family != AF_INET) continue;
+#endif
+
       /* Print what we are doing. */
       {
         char topbuf[512];
@@ -931,12 +934,6 @@ main (int argc, char **argv)
       exit (1);
     }
 
-  if ((ret = gnutls_global_init_extra ()) < 0)
-    {
-      fprintf (stderr, "global_init_extra: %s\n", gnutls_strerror (ret));
-      exit (1);
-    }
-
 #ifdef ENABLE_PKCS11
   pkcs11_common ();
 #endif
