@@ -106,16 +106,17 @@ do_handshake (gnutls_session_t session)
 }
 
 char protocol_str[] = "+VERS-TLS1.0:+VERS-SSL3.0";
-char prio_str[256] = "";
+char protocol_all_str[] = "+VERS-TLS1.2:+VERS-TLS1.1:+VERS-TLS1.0:+VERS-SSL3.0";
+char prio_str[512] = "";
 
 #define ALL_CIPHERS "+3DES-CBC:+ARCFOUR-128:+ARCFOUR-40"
 #define BLOCK_CIPHERS "+3DES-CBC:+AES-128-CBC"
 #define ALL_COMP "+COMP-NULL"
 #define ALL_MACS "+SHA1:+MD5"
 #define ALL_CERTTYPES "+CTYPE-X509"
-#define ALL_KX "+RSA:+DHE-RSA:+DHE-DSS:+ANON-DH:+RSA-EXPORT"
+#define ALL_KX "+RSA:+DHE-RSA:+DHE-DSS:+ANON-DH:+RSA-EXPORT:+ECDHE-RSA:+ECDHE-ECDSA:+ANON-ECDH"
 #define INIT_STR "NONE:"
-char rest[128] = "%UNSAFE_RENEGOTIATION";
+char rest[128] = "%UNSAFE_RENEGOTIATION:+SIGN-ALL:+CURVE-ALL";
 
 static inline void
 _gnutls_priority_set_direct (gnutls_session_t session, const char *str)
@@ -258,6 +259,7 @@ test_export_info (gnutls_session_t session)
 }
 
 static gnutls_datum_t pubkey = { NULL, 0 };
+static gnutls_ecc_curve_t curve = GNUTLS_ECC_CURVE_INVALID;
 
 test_code_t
 test_dhe (gnutls_session_t session)
@@ -278,6 +280,24 @@ test_dhe (gnutls_session_t session)
   return ret;
 }
 
+test_code_t test_ecdhe (gnutls_session_t session)
+{
+  int ret;
+
+  sprintf (prio_str, INIT_STR
+           ALL_CIPHERS ":" ALL_COMP ":" ALL_CERTTYPES ":%s:" ALL_MACS
+           ":+ECDHE-RSA:+ECDHE-ECDSA:+CURVE-ALL:%s", protocol_all_str, rest);
+  _gnutls_priority_set_direct (session, prio_str);
+
+  gnutls_credentials_set (session, GNUTLS_CRD_CERTIFICATE, xcred);
+
+  ret = do_handshake (session);
+
+  curve = gnutls_ecc_curve_get(session);
+
+  return ret;
+}
+
 
 test_code_t
 test_safe_renegotiation (gnutls_session_t session)
@@ -358,6 +378,17 @@ test_dhe_group (gnutls_session_t session)
   return ret;
 }
 
+test_code_t
+test_ecdhe_curve (gnutls_session_t session)
+{
+  if (curve == GNUTLS_ECC_CURVE_INVALID)
+    return TEST_IGNORE;
+
+  printf ("\n Curve %s", gnutls_ecc_curve_get_name(curve));
+
+  return TEST_SUCCEED;
+}
+
 test_code_t
 test_ssl3 (gnutls_session_t session)
 {
@@ -458,7 +489,21 @@ test_aes (gnutls_session_t session)
   return ret;
 }
 
-#ifdef	ENABLE_CAMELLIA
+test_code_t test_aes_gcm (gnutls_session_t session)
+{
+  int ret;
+
+  sprintf (prio_str, INIT_STR
+           "+AES-128-GCM:+AES-256-GCM:+AEAD:" ALL_COMP ":" ALL_CERTTYPES ":%s:" ALL_MACS
+           ":" ALL_KX ":%s", protocol_all_str, rest);
+  _gnutls_priority_set_direct (session, prio_str);
+
+  gnutls_credentials_set (session, GNUTLS_CRD_CERTIFICATE, xcred);
+
+  ret = do_handshake (session);
+  return ret;
+}
+
 test_code_t
 test_camellia (gnutls_session_t session)
 {
@@ -474,7 +519,6 @@ test_camellia (gnutls_session_t session)
   ret = do_handshake (session);
   return ret;
 }
-#endif
 
 test_code_t
 test_openpgp1 (gnutls_session_t session)
@@ -503,18 +547,10 @@ test_unknown_ciphersuites (gnutls_session_t session)
 {
   int ret;
 
-
-#ifdef	ENABLE_CAMELLIA
-  sprintf (prio_str,
-           INIT_STR ALL_CIPHERS ":" ALL_COMP ":" ALL_CERTTYPES ":%s:" ALL_MACS
-           ":" ALL_KX ":%s", protocol_str, rest);
-  _gnutls_priority_set_direct (session, prio_str);
-#else
   sprintf (prio_str,
            INIT_STR "+AES-128-CBC:" ALL_CIPHERS ":" ALL_COMP ":" ALL_CERTTYPES
            ":%s:" ALL_MACS ":" ALL_KX ":%s", protocol_str, rest);
   _gnutls_priority_set_direct (session, prio_str);
-#endif
 
   gnutls_credentials_set (session, GNUTLS_CRD_CERTIFICATE, xcred);
 
@@ -571,6 +607,21 @@ test_sha (gnutls_session_t session)
   return ret;
 }
 
+test_code_t
+test_sha256 (gnutls_session_t session)
+{
+  int ret;
+
+  sprintf (prio_str,
+           INIT_STR "+AES-128-CBC:" ALL_CIPHERS ":" ALL_COMP ":" ALL_CERTTYPES
+           ":%s:+SHA256:" ALL_KX ":%s", protocol_all_str, rest);
+  _gnutls_priority_set_direct (session, prio_str);
+  gnutls_credentials_set (session, GNUTLS_CRD_CERTIFICATE, xcred);
+
+  ret = do_handshake (session);
+  return ret;
+}
+
 test_code_t
 test_3des (gnutls_session_t session)
 {
@@ -811,6 +862,22 @@ test_hello_extension (gnutls_session_t session)
 {
   int ret;
 
+  sprintf (prio_str,
+           INIT_STR ALL_CIPHERS ":" ALL_COMP ":" ALL_CERTTYPES ":%s:" ALL_MACS
+           ":" ALL_KX ":%s", protocol_str, rest);
+  _gnutls_priority_set_direct (session, prio_str);
+  gnutls_credentials_set (session, GNUTLS_CRD_CERTIFICATE, xcred);
+  gnutls_record_set_max_size (session, 4096);
+
+  ret = do_handshake (session);
+  return ret;
+}
+
+test_code_t
+test_small_records (gnutls_session_t session)
+{
+  int ret;
+
   sprintf (prio_str,
            INIT_STR ALL_CIPHERS ":" ALL_COMP ":" ALL_CERTTYPES ":%s:" ALL_MACS
            ":" ALL_KX ":%s", protocol_str, rest);
@@ -911,7 +978,7 @@ test_anonymous (gnutls_session_t session)
 
   sprintf (prio_str,
            INIT_STR ALL_CIPHERS ":" ALL_COMP ":" ALL_CERTTYPES ":%s:" ALL_MACS
-           ":+ANON-DH:%s", protocol_str, rest);
+           ":+ANON-DH:+ANON-ECDH:+CURVE-ALL:%s", protocol_str, rest);
   _gnutls_priority_set_direct (session, prio_str);
   gnutls_credentials_set (session, GNUTLS_CRD_ANON, anon_cred);
 
